VOC Roadmap
===========

VOC is a new project - we have lots of things that we'd like to do. If
you'd like to contribute, providing a patch for one of these features:

* Port a set of basic type operations

* Implement a Python standard library module for

* Implement StackMapFrames for the generated Java class files.

* Work out how to run the CPython test suite with VOC
